==> haskell-blaze-builder-0.4.0.2-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-blaze-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: blaze-builder
version: 0.4.0.2
id: blaze-builder-0.4.0.2-EbETJDFSQ4b6W7B283dutO
key: blaze-builder-0.4.0.2-EbETJDFSQ4b6W7B283dutO
license: BSD3
copyright: (c) 2010-2014 Simon Meier
           (c) 2010 Jasper Van der Jeugt
           (c) 2013-2015 Leon P Smith
maintainer: Leon Smith <leon@melding-monads.com>
stability: Experimental
homepage: http://github.com/lpsmith/blaze-builder
synopsis: Efficient buffered output.
description:
    This library provides an implementation of the older
    blaze-builder interface in terms of the new builder that
    shipped with bytestring-0.10.4.0
    .
    This implementation is mostly intended as a bridge to the
    new builder,  so that code that uses the old interface
    can interoperate with code that uses the new
    implementation.   Note that no attempt has been made
    to preserve the old internal modules,  so code that
    has these dependencies cannot use this interface.
    .
    New code should,  for the most part,  use the new
    interface.   However, this module does implement
    a chunked HTTP encoding,  which is not otherwise
    implemented (yet?) with the new builder.
category: Data
author: Jasper Van der Jeugt, Simon Meier, Leon P Smith
exposed: True
exposed-modules:
    Blaze.ByteString.Builder Blaze.ByteString.Builder.Int
    Blaze.ByteString.Builder.Word Blaze.ByteString.Builder.ByteString
    Blaze.ByteString.Builder.Char.Utf8 Blaze.ByteString.Builder.Char8
    Blaze.ByteString.Builder.Html.Utf8 Blaze.ByteString.Builder.HTTP
    Blaze.ByteString.Builder.Compat.Write
    Blaze.ByteString.Builder.Internal.Write
abi: 59c1dae6bdf0aa910981dfc9db884e5e
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/blaze-builder-0.4.0.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/blaze-builder-0.4.0.2
dynamic-library-dirs: /usr/lib/x86_64-linux-ghc-8.0.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/blaze-builder-0.4.0.2
hs-libraries: HSblaze-builder-0.4.0.2-EbETJDFSQ4b6W7B283dutO
depends:
    base-4.9.1.0 bytestring-0.10.8.1 deepseq-1.4.2.0
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
haddock-interfaces: /usr/share/doc/haskell-blaze-builder/html/blaze-builder.haddock
haddock-html: /usr/share/doc/haskell-blaze-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-blaze-builder-0.4.0.2-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-blaze-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: blaze-builder
version: 0.4.0.2
id: blaze-builder-0.4.0.2-9jN75sESh05JfWRLWr51Wl
key: blaze-builder-0.4.0.2-9jN75sESh05JfWRLWr51Wl
license: BSD3
copyright: (c) 2010-2014 Simon Meier
           (c) 2010 Jasper Van der Jeugt
           (c) 2013-2015 Leon P Smith
maintainer: Leon Smith <leon@melding-monads.com>
stability: Experimental
homepage: http://github.com/lpsmith/blaze-builder
synopsis: Efficient buffered output.
description:
    This library provides an implementation of the older
    blaze-builder interface in terms of the new builder that
    shipped with bytestring-0.10.4.0
    .
    This implementation is mostly intended as a bridge to the
    new builder,  so that code that uses the old interface
    can interoperate with code that uses the new
    implementation.   Note that no attempt has been made
    to preserve the old internal modules,  so code that
    has these dependencies cannot use this interface.
    .
    New code should,  for the most part,  use the new
    interface.   However, this module does implement
    a chunked HTTP encoding,  which is not otherwise
    implemented (yet?) with the new builder.
category: Data
author: Jasper Van der Jeugt, Simon Meier, Leon P Smith
exposed: True
indefinite: False
exposed-modules:
    Blaze.ByteString.Builder Blaze.ByteString.Builder.ByteString
    Blaze.ByteString.Builder.Char.Utf8 Blaze.ByteString.Builder.Char8
    Blaze.ByteString.Builder.Compat.Write Blaze.ByteString.Builder.HTTP
    Blaze.ByteString.Builder.Html.Utf8 Blaze.ByteString.Builder.Int
    Blaze.ByteString.Builder.Internal.Write
    Blaze.ByteString.Builder.Word
abi: 92c6d3f9634de2495e94b00787c1e242
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/blaze-builder-0.4.0.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/blaze-builder-0.4.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/blaze-builder-0.4.0.2
hs-libraries: HSblaze-builder-0.4.0.2-9jN75sESh05JfWRLWr51Wl
depends:
    base-4.10.0.0 deepseq-1.4.3.0 text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    bytestring-0.10.8.2
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             deepseq-1.4.3.0=5db6f9c28d6213bd6646f988460dacd0
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=9217a19661a41b462c62d1a4bdf2e9b1
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
haddock-interfaces: /usr/share/doc/haskell-blaze-builder/html/blaze-builder.haddock
haddock-html: /usr/share/doc/haskell-blaze-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
